"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = require("fs");
const path_1 = require("path");
const TransformRunner_1 = require("./TransformRunner");
/**
 * Builds an iterator that loops through all the files in the given paths,
 * matching a whitelist of extensions and not matched by the ignore predicate.
 */
function* iterateSources(paths, extensions, ignore, statSyncImpl = fs_1.statSync, readdirSyncImpl = fs_1.readdirSync, readFileSyncImpl = fs_1.readFileSync) {
    for (let path of paths) {
        let stats = statSyncImpl(path);
        if (stats.isDirectory()) {
            for (let child of readdirSyncImpl(path)) {
                let childPath = path_1.join(path, child);
                let childStat = statSyncImpl(childPath);
                if (ignore(childPath, child, path, childStat)) {
                    continue;
                }
                if (childStat.isFile()) {
                    if (extensions.has(path_1.extname(child))) {
                        yield* iterateSources([childPath], extensions, ignore, statSyncImpl, readdirSyncImpl, readFileSyncImpl);
                    }
                }
                else if (childStat.isDirectory()) {
                    yield* iterateSources([childPath], extensions, ignore, statSyncImpl, readdirSyncImpl, readFileSyncImpl);
                }
            }
        }
        else if (stats.isFile()) {
            yield new TransformRunner_1.Source(path, readFileSyncImpl(path, { encoding: 'utf8' }));
        }
    }
}
exports.default = iterateSources;
//# sourceMappingURL=iterateSources.js.map