"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = require("mz/fs");
const path_1 = require("path");
const transpile_requires_1 = require("../transpile-requires");
function isFile(path) {
    return __awaiter(this, void 0, void 0, function* () {
        try {
            return (yield fs_1.stat(path)).isFile();
        }
        catch (_a) {
            return false;
        }
    });
}
/**
 * Resolves file system paths to plugins.
 */
class FileSystemResolver {
    constructor(optionalExtensions = transpile_requires_1.SUPPORTED_EXTENSIONS) {
        this.optionalExtensions = optionalExtensions;
    }
    *enumerateCandidateSources(source) {
        yield path_1.resolve(source);
        for (let ext of this.optionalExtensions) {
            if (ext[0] !== '.') {
                yield path_1.resolve(`${source}.${ext}`);
            }
            else {
                yield path_1.resolve(source + ext);
            }
        }
    }
    canResolve(source) {
        return __awaiter(this, void 0, void 0, function* () {
            for (let candidate of this.enumerateCandidateSources(source)) {
                if (yield isFile(candidate)) {
                    return true;
                }
            }
            return false;
        });
    }
    resolve(source) {
        return __awaiter(this, void 0, void 0, function* () {
            for (let candidate of this.enumerateCandidateSources(source)) {
                if (yield isFile(candidate)) {
                    return candidate;
                }
            }
            throw new Error(`unable to resolve file from source: ${source}`);
        });
    }
}
exports.default = FileSystemResolver;
//# sourceMappingURL=FileSystemResolver.js.map