"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@babel/core");
const path_1 = require("path");
const pirates_1 = require("pirates");
let useBabelrc = false;
let revert = null;
exports.SUPPORTED_EXTENSIONS = new Set([
    '.js',
    '.jsx',
    '.es',
    '.es6',
    '.mjs',
    '.ts'
]);
function hook(code, filename) {
    let ext = path_1.extname(filename);
    if (!exports.SUPPORTED_EXTENSIONS.has(ext)) {
        throw new Error(`cannot load file type '${ext}': ${filename}`);
    }
    let options = {
        filename,
        babelrc: useBabelrc,
        presets: [],
        sourceMaps: 'inline'
    };
    if (!useBabelrc) {
        if (ext === '.ts') {
            options.presets.push(require('@babel/preset-typescript').default());
        }
        options.presets.push(require('@babel/preset-env').default());
    }
    return core_1.transform(code, options).code;
}
exports.hook = hook;
function enable(babelrc = false) {
    disable();
    useBabelrc = babelrc;
    revert = pirates_1.addHook(hook, {
        exts: Array.from(exports.SUPPORTED_EXTENSIONS),
        ignoreNodeModules: true
    });
}
exports.enable = enable;
function disable() {
    if (revert) {
        revert();
        revert = null;
    }
}
exports.disable = disable;
//# sourceMappingURL=transpile-requires.js.map